@@ -10,6 +10,12 @@ test_that("Score tree works", {
     expect_equal(round(l, 3), -1606.497)
 })
 
+test_that("Score tree C++ works", {
+    tree_small = reorder(tree_small, order = 'postorder')
+    l = score_tree_cpp(tree_small$edge, P_small)
+    expect_equal(round(l, 3), -1606.497)
+})
+
 # test_that("Conversion between phylo and tree graph works", {
 #     tree_small_new = to_phylo(annotate_tree(tree_small, P_small))
 #     l0 = score_tree(to_phylo(gtree_small), P_small)$l_tree
